@@ -48,15 +48,7 @@ class Node(Component):
                                               parent=self, **pipes)
         return msgbox
 
-    _dependent_statuses = {'exited'}
-
-    async def test(self, messages):
-        self.debug(f'~~~~~~ begin {messages}')
-        async for c, m in messages:
-            self.debug(f'~~~~~~ message from {messages} {c} {m}')
-            yield c, m
-            self.debug(f'~~~~~~ yielded from {messages} {c} {m}')
-        self.debug(f'~~~~~~ end {messages}')
+    _dependent_statuses = set()
 
     def start(self, *args):
         coroutines = [super().start(*args)]
